==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/creatures/dialogs_es.lua <==

dialogId("kor-m-podivej", "font_small", "Look at all these lobsters...")
dialogStr("Mira todas esas langostas...")


dialogId("kor-v-spitu", "font_big", "They sleep for thousands of years... in eternal stillness...")
dialogStr("Ellas duermen por cientos de años... en eterna quietud...")


dialogId("kor-m-avlada", "font_small", "...and the government tries to cover it up.")
dialogStr("...y el gobierno trata de ocultarlo.")


dialogId("kor-v-nicje", "font_big", "...nothing can wake them up...")
dialogStr("...nada puede despertarlos...")


dialogId("kor-m-pokud", "font_small", "Unless we activate that octopus.")
dialogStr("A menos que pongamos en movimiento a ese pulpo.")


dialogId("kor-v-podivej", "font_big", "Look, everything here is so still and quiet.")
dialogStr("Mira, todo aquí es tan quieto y silencioso.")


dialogId("kor-m-vzdyt", "font_small", "But the anemones are moving.")
dialogStr("Pero las anémonas se mueven.")


dialogId("kor-v-treba", "font_big", "Maybe they`re in the throes of death.")
dialogStr("Quizás están agonizando.")


dialogId("kor-v-shledavam", "font_big", "I find a certain symbolism in that.")
dialogStr("Encuentro cierto simbolismo en aquello.")


dialogId("kor-v-bermudy", "font_big", "That`s interesting. This type of coral normally grows only in the Bermuda Triangle.")
dialogStr("Eso es interesante. Este tipo de coral normalmente crece sólo en el Triángulo de las Bermudas.")


dialogId("kor-v-inteligentni", "font_big", "Did you know that some types of coral are almost as intelligent as fish?")
dialogStr("¿Sabías que algunos tipos de coral son casi tan inteligentes como los peces?")


dialogId("kor-v-jedovate", "font_big", "Be careful, most types of coral are poisonous.")
dialogStr("Ten cuidado, la mayoría de los tipos de coral son venenosos.")


dialogId("kor-m-dusi", "font_small", "What do you think, is there such a thing as a 'coral-soul`?")
dialogStr("¿Que es lo que piensas, que hay algo así como una \"alma-coral\"?")


dialogId("kor-m-pocit", "font_small", "Do you have the feeling that those coral are watching us?")
dialogStr("¿No tienes la sensación de que esos corales nos están mirando?")


dialogId("kor-m-bizarni", "font_small", "I wonder why the coral have such a bizarre shape.")
dialogStr("Me pregunto porqué el coral tiene una forma tan extraña.")


dialogId("kor-v-juchacka", "font_big", "That was some number, wasn`t it?")
dialogStr("Ese era una leyenda, ¿Cierto?")


dialogId("kor-m-hraje", "font_small", "Yeah, he`s a great player.")
dialogStr("Si, fué un gran jugador.")


dialogId("kor-v-odvaz", "font_big", "That`s cool. What if we pushed him again?")
dialogStr("Eso es genial. ¿Que tal si lo empujamos de nuevo?")


dialogId("kor-m-vsimlsis", "font_small", "Did you see what the lobsters were doing?")
dialogStr("¿Viste lo que esas langostas estaban haciendo?")


dialogId("kor-v-avidelas", "font_big", "And how those anemones were dancing?")
dialogStr("¿Y esas anémonas como estaban bailando?")


dialogId("kor-m-tovis", "font_small", "Well, you know, it`s not all that much fun down here at the bottom of the ocean.")
dialogStr("Bueno, tu sabes, esa no es toda la diversión aquí en el fondo del océano.")


dialogId("kor-v-vali", "font_big", "He`s good, isn`t he?")
dialogStr("El es bueno, ¿No es cierto?")


dialogId("kor-m-nachob", "font_small", "Not bad for an octopus...")
dialogStr("No está mal para ser un pulpo...")


dialogId("kor-m-jinou", "font_small", "Do you think he knows any other tune?")
dialogStr("¿Crees que conozca otras melodías?")


dialogId("kor-m-neprehani", "font_small", "Don`t you think we`ve had enough already?")
dialogStr("¿No crees que ya tuvimos demasiado?")


dialogId("kor-m-lezekrkem", "font_small", "I`m getting sick of it...")
dialogStr("Esto me está enfermando...")


dialogId("kor-v-lezekrkem", "font_big", "I`m sick and tired of it...")
dialogStr("Estoy cansado y enfermo de esto...")


dialogId("kor-v-kostice", "font_big", "I`m fed up to the gills with this.")
dialogStr("Estoy hasta las agallas con esto.")


dialogId("kor-v-odsud", "font_big", "I can`t budge this from where I am. I`d have to try to move it from the left side.")
dialogStr("No puedo quitar esto desde donde estoy. Voy a tener que tratar de moverlo desde el otro lado.")


dialogId("kor-m-budesmuset", "font_small", "Well you`ll have to go that way through those anemones.")
dialogStr("Bueno, tendrás que ir por ese camino, entre esas anémonas.")


dialogId("kor-m-neniono", "font_small", "That`s not what I had in mind...")
dialogStr("Eso no es lo que tenía en mente...")


dialogId("kor-m-tudiru", "font_small", "We should have plugged that hole beforehand.")
dialogStr("Deberíamos de haber tapado ese agujero antes que nada.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/creatures/dialogs_es.lua <==

dialogId("kor-m-podivej", "font_small", "Look at all these lobsters...")
dialogStr("Mira todas esas langostas...")


dialogId("kor-v-spitu", "font_big", "They sleep for thousands of years... in eternal stillness...")
dialogStr("Ellas duermen por cientos de años... en eterna quietud...")


dialogId("kor-m-avlada", "font_small", "...and the government tries to cover it up.")
dialogStr("...y el gobierno trata de ocultarlo.")


dialogId("kor-v-nicje", "font_big", "...nothing can wake them up...")
dialogStr("...nada puede despertarlos...")


dialogId("kor-m-pokud", "font_small", "Unless we activate that octopus.")
dialogStr("A menos que pongamos en movimiento a ese pulpo.")


dialogId("kor-v-podivej", "font_big", "Look, everything here is so still and quiet.")
dialogStr("Mira, todo aquí es tan quieto y silencioso.")


dialogId("kor-m-vzdyt", "font_small", "But the anemones are moving.")
dialogStr("Pero las anémonas se mueven.")


dialogId("kor-v-treba", "font_big", "Maybe they’re in the throes of death.")
dialogStr("Quizás están agonizando.")


dialogId("kor-v-shledavam", "font_big", "I find a certain symbolism in that.")
dialogStr("Encuentro cierto simbolismo en aquello.")


dialogId("kor-v-bermudy", "font_big", "That’s interesting. This type of coral normally grows only in the Bermuda Triangle.")
dialogStr("Eso es interesante. Este tipo de coral normalmente crece sólo en el Triángulo de las Bermudas.")


dialogId("kor-v-inteligentni", "font_big", "Did you know that some types of coral are almost as intelligent as fish?")
dialogStr("¿Sabías que algunos tipos de coral son casi tan inteligentes como los peces?")


dialogId("kor-v-jedovate", "font_big", "Be careful, most types of coral are poisonous.")
dialogStr("Ten cuidado, la mayoría de los tipos de coral son venenosos.")


dialogId("kor-m-dusi", "font_small", "What do you think, is there such a thing as a 'coral-soul’?")
dialogStr("¿Que es lo que piensas, que hay algo así como una \"alma-coral\"?")


dialogId("kor-m-pocit", "font_small", "Do you have the feeling that those coral are watching us?")
dialogStr("¿No tienes la sensación de que esos corales nos están mirando?")


dialogId("kor-m-bizarni", "font_small", "I wonder why the coral have such a bizarre shape.")
dialogStr("Me pregunto porqué el coral tiene una forma tan extraña.")


dialogId("kor-v-juchacka", "font_big", "That was some number, wasn’t it?")
dialogStr("Ese era una leyenda, ¿Cierto?")


dialogId("kor-m-hraje", "font_small", "Yeah, he’s a great player.")
dialogStr("Si, fué un gran jugador.")


dialogId("kor-v-odvaz", "font_big", "That’s cool. What if we pushed him again?")
dialogStr("Eso es genial. ¿Que tal si lo empujamos de nuevo?")


dialogId("kor-m-vsimlsis", "font_small", "Did you see what the lobsters were doing?")
dialogStr("¿Viste lo que esas langostas estaban haciendo?")


dialogId("kor-v-avidelas", "font_big", "And how those anemones were dancing?")
dialogStr("¿Y esas anémonas como estaban bailando?")


dialogId("kor-m-tovis", "font_small", "Well, you know, it’s not all that much fun down here at the bottom of the ocean.")
dialogStr("Bueno, tu sabes, esa no es toda la diversión aquí en el fondo del océano.")


dialogId("kor-v-vali", "font_big", "He’s good, isn’t he?")
dialogStr("El es bueno, ¿No es cierto?")


dialogId("kor-m-nachob", "font_small", "Not bad for an octopus...")
dialogStr("No está mal para ser un pulpo...")


dialogId("kor-m-jinou", "font_small", "Do you think he knows any other tune?")
dialogStr("¿Crees que conozca otras melodías?")


dialogId("kor-m-neprehani", "font_small", "Don’t you think we’ve had enough already?")
dialogStr("¿No crees que ya tuvimos demasiado?")


dialogId("kor-m-lezekrkem", "font_small", "I’m getting sick of it...")
dialogStr("Esto me está enfermando...")


dialogId("kor-v-lezekrkem", "font_big", "I’m sick and tired of it...")
dialogStr("Estoy cansado y enfermo de esto...")


dialogId("kor-v-kostice", "font_big", "I’m fed up to the gills with this.")
dialogStr("Estoy hasta las agallas con esto.")


dialogId("kor-v-odsud", "font_big", "I can’t budge this from where I am. I’d have to try to move it from the left side.")
dialogStr("No puedo quitar esto desde donde estoy. Voy a tener que tratar de moverlo desde el otro lado.")


dialogId("kor-m-budesmuset", "font_small", "Well you’ll have to go that way through those anemones.")
dialogStr("Bueno, tendrás que ir por ese camino, entre esas anémonas.")


dialogId("kor-m-neniono", "font_small", "That’s not what I had in mind...")
dialogStr("Eso no es lo que tenía en mente...")


dialogId("kor-m-tudiru", "font_small", "We should have plugged that hole beforehand.")
dialogStr("Deberíamos de haber tapado ese agujero antes que nada.")
